local Crider = {}
Crider.__index = Crider

function Crider.new( x, y, img, frames, sz, y_off )
	local self 		= setmetatable({}, Crider)
	self.x			= x
	self.y			= y
	self.IMG		= love.graphics.newImage(img)
	self.frames		= {}
	self.frame		= 0			-- current frame
	self.facing		= 1			-- 1 = right, -1 = left
	self.xvelocity	= 0			-- measured in pixels per second
	self.yvelocity 	= 0
	self.yaccel		= 1000		-- measured in pixels per second per second
	self.onGround	= false
	self.sz			= sz
	for i = 0, frames - 1 do
		self.frames[i] = love.graphics.newQuad(self.sz*i, y_off, self.sz, self.sz, self.IMG:getWidth(), self.IMG:getHeight()) end
	return self
end

function Crider:update( dt )
	self.frame = ( 10 * love.timer.getTime() ) % #self.frames -- frames per second
	self:input()				-- receive user input

	-- apply acceleration and velocity, set coordinates accordingly
	self.yvelocity	= self.yvelocity + (self.yaccel * dt)
	self.x			= self.x + (self.xvelocity * dt)
	self.y			= self.y + (self.yvelocity * dt)
	if self.y >= lineY  then
		self.y = lineY
	end

	if not self.onGround and self.y >= lineY - 1 then
		self.onGround	= true
		self.yvelocity	= 0
	end
end

function Crider:draw()
	-- offset to the center at his feet
	love.graphics.drawq(
		self.IMG, self.frames[math.floor(self.frame)],
		math.floor(self.x), math.floor(self.y),
		0, self.facing, 1, self.sz, self.sz)
end

function Crider:input()
	if love.keyboard.isDown("right") then
		self.facing		= 1
		self.xvelocity	= 100
	elseif love.keyboard.isDown("left") then
		self.facing		= -1
		self.xvelocity	= -100
	else
		self.xvelocity	= 0
	end
	if self.onGround and love.keyboard.isDown("up") then
		self.onGround	= false
		self.yvelocity	= -300
	end
end

return Crider
